@@ -118,7 +118,7 @@ class Param:
 class rtnCode(Enum):
     Success = {"rtnCode": "0000", "rtnMsg": "操作成功", "rtnDesc": ""},
     Failure = {"rtnCode": "1000", "rtnMsg": "操作失败", "rtnDesc": ""},
-    ParamError = {"rtnCode": "1001", "rtnMsg": "缺少参数/参数格式错误"},
+    ParamError = {"rtnCode": "1001", "rtnMsg": "缺少参数/参数错误/参数格式错误"},
     BizParamError = {"rtnCode": "1002", "rtnMsg": "业务参数异常"},
     # Auth
     AuthError = {"rtnCode": "2000", "rtnMsg": "接口授权信息异常"},
